==> schemacrawler-16.18.2-sources.jar: schemacrawler/tools/databaseconnector/UnknownDatabaseConnector.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2022, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/
package schemacrawler.tools.databaseconnector;

import schemacrawler.schemacrawler.DatabaseServerType;
import us.fatehi.utility.datasource.DatabaseConnectionSourceBuilder;

final class UnknownDatabaseConnector extends DatabaseConnector {

  /** Constructor for unknown databases. Bypass the null-checks of the main constructor */
  UnknownDatabaseConnector() {
    super(
        DatabaseServerType.UNKNOWN,
        url -> false,
        (informationSchemaViewsBuilder, connection) -> {},
        (schemaRetrievalOptionsBuilder, connection) -> {},
        limitOptionsBuilder -> {},
        () -> DatabaseConnectionSourceBuilder.builder(""));
  }
}

==> schemacrawler-16.20.4-sources.jar: schemacrawler/tools/databaseconnector/UnknownDatabaseConnector.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2023, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.tools.databaseconnector;

import schemacrawler.schemacrawler.DatabaseServerType;
import us.fatehi.utility.datasource.DatabaseConnectionSourceBuilder;

public final class UnknownDatabaseConnector extends DatabaseConnector {

  public static final DatabaseConnector UNKNOWN = new UnknownDatabaseConnector();

  /** Constructor for unknown databases. Bypass the null-checks of the main constructor */
  private UnknownDatabaseConnector() {
    super(
        DatabaseServerType.UNKNOWN,
        url -> false,
        (informationSchemaViewsBuilder, connection) -> {},
        (schemaRetrievalOptionsBuilder, connection) -> {},
        limitOptionsBuilder -> {},
        () -> DatabaseConnectionSourceBuilder.builder(""));
  }
}
